#!/bin/sh

pip install -e ".[dev]"
python3 -m pip install --upgrade pip build twine
python3 -m build
# python3 -m twine upload --repository testpypi dist/*
python3 -m twine upload --repository pypi dist/*